Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(362)

Unified Diff: third_party/WebKit/Source/platform/scheduler/CancellableTaskFactory.h

Issue 1549143002: Add thread affinity and ASSERT() for same-thread restriction to WTF::Function (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@TRV_ThreadSafeBindByVariadicTemplate
Patch Set: Rebase. Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/scheduler/CancellableTaskFactory.h
diff --git a/third_party/WebKit/Source/platform/scheduler/CancellableTaskFactory.h b/third_party/WebKit/Source/platform/scheduler/CancellableTaskFactory.h
index 46c26bde430fefa346156e5aa1b954e3c0d361ff..8b54a781330c8a2958b95bfcf92ffcdbcddeb299 100644
--- a/third_party/WebKit/Source/platform/scheduler/CancellableTaskFactory.h
+++ b/third_party/WebKit/Source/platform/scheduler/CancellableTaskFactory.h
@@ -29,7 +29,7 @@ public:
// CancellableTaskFactory, and one when that owning object isn't controlled
// by Oilpan.
//
// In the Oilpan case, as WTF::Closure objects are off-heap, we have to construct the
// closure in such a manner that it doesn't end up referring back to the owning heap
// object with a strong Persistent<> GC root reference. If we do, this will create
// a heap <-> off-heap cycle and leak, the owning object can never be GCed.
@@ -62,7 +62,7 @@ public:
protected:
// Only intended used by unit tests wanting to stack allocate and/or pass in a closure value.
// Please use the create() factory method elsewhere.
- explicit CancellableTaskFactory(PassOwnPtr<Closure> closure)
+ explicit CancellableTaskFactory(PassOwnPtr<SameThreadClosure> closure)
: m_closure(std::move(closure))
, m_weakPtrFactory(this)
{
@@ -85,7 +85,7 @@ private:
WeakPtr<CancellableTaskFactory> m_weakPtr;
};
- OwnPtr<Closure> m_closure;
+ OwnPtr<SameThreadClosure> m_closure;
WeakPtrFactory<CancellableTaskFactory> m_weakPtrFactory;
};
@@ -29,7 +29,7 @@ public:
// by Oilpan.
//
- // In the Oilpan case, as WTF::Closure objects are off-heap, we have to construct the
+ // In the Oilpan case, as WTF::SameThreadClosure objects are off-heap, we have to construct the
// closure in such a manner that it doesn't end up referring back to the owning heap
// object with a strong Persistent<> GC root reference. If we do, this will create

Powered by Google App Engine
This is Rietveld 408576698